@@ -3,11 +3,14 @@
 #' @param x A vector of Decimal odds
 #'
 #' @return A vector of Indonesian odds
-#' 
+#'
 #'@export
-#' 
+#'
 #' @examples
 #' odds.dec2indo(c(1.93,2.05))
 odds.dec2indo <- function (x) {
-        ifelse (x <= 1,NA,odds.us2indo(odds.dec2us(x)))
+  indo <- x
+  indo[] <- NA_real_
+  indo[which(x > 1)] <- odds.dec2us(x[which(x > 1)]) / 100
+  indo
 }
