@@ -9,5 +9,8 @@
 #' @examples
 #' odds.dec2malay(c(1.93,2.05))
 odds.dec2malay <- function (x) {
-        ifelse (x <= 1,NA,odds.us2malay(odds.dec2us(x)))
+  malay <- x
+  malay[] <- NA_real_
+  malay[which(x > 1)] <- odds.us2malay(odds.dec2us(x[which(x > 1)]))
+  malay
 }
