@@ -9,6 +9,9 @@
 #' @examples
 #' odds.dec2us(c(1.93,2.05))
 odds.dec2us <- function (x) {
-        ifelse (x <= 1,NA,
-                ifelse(x >2, 100 * (x - 1), -100 / (x - 1)))
+  us <- x
+  us[] <- NA_real_  
+  us[which(x > 1)] <- -100 / (x[which(x > 1)] - 1)
+  us[which(x > 2)] <- 100 * (x[which(x > 2)] - 1)
+  us
 }
