@@ -8,6 +8,9 @@
 #'
 #' @examples
 #' odds.hk2dec(c(1.93,0.05))
-odds.hk2dec <- function (x){
-        ifelse (x <= 0,NA,x+1)
-}
\ No newline at end of file
+odds.hk2dec <- function (x) {
+  dec <- x
+  dec[] <- NA_real_
+  dec[which(x > 0)] <- x[which(x > 0)] + 1
+  dec
+}
