@@ -8,6 +8,9 @@
 #'
 #' @examples
 #' odds.hk2indo(c(1.93,0.05))
-odds.hk2indo <- function (x){
-        ifelse (x <= 0,NA,odds.us2indo(odds.hk2us(x)))
-}
\ No newline at end of file
+odds.hk2indo <- function (x) {
+  indo <- x
+  indo[] <- NA_real_
+  indo[which(x > 0)] <- odds.hk2us(x[which(x > 0)]) / 100
+  indo
+}
