@@ -8,6 +8,10 @@
 #'
 #' @examples
 #' odds.hk2us(c(1.93,0.05))
-odds.hk2us <- function (x){
-        ifelse (x <= 0,NA,ifelse(x > 1, 100*x,-100/x))
-}
\ No newline at end of file
+odds.hk2us <- function (x) {
+  us <- x
+  us[] <- NA_real_
+  us[which(x > 0)] <- -100 / x[which(x > 0)]
+  us[which(x > 1)] <- 100 * x[which(x > 1)]
+  us
+}
