@@ -9,5 +9,9 @@
 #' @examples
 #' odds.indo2hk(c(1.93,2.05))
 odds.indo2hk <- function (x) {
-        ifelse (x > -1 & x < 1,NA,odds.us2hk(odds.indo2us(x)))
-}
\ No newline at end of file
+  hk <- x
+  hk[] <- NA_real_
+  hk[which(x <= -1)] <- -1 / x[which(x <= -1)]
+  hk[which(x >= 1)] <- x[which(x >= 1)]
+  hk
+}
