@@ -9,5 +9,8 @@
 #' @examples
 #' odds.indo2malay(c(1.93,2.05))
 odds.indo2malay <- function (x) {
-        ifelse (x > -1 & x < 1,NA,odds.us2malay(odds.indo2us(x)))
-}
\ No newline at end of file
+  malay <- x
+  malay[] <- NA_real_
+  malay[which(x <= -1 | x >= 1)] <- -1 / x[which(x <= -1 | x >= 1)]
+  malay
+}
