@@ -8,6 +8,10 @@
 #'
 #' @examples
 #' odds.indo2hk(c(1.93,2.05))
-odds.indo2prob <- function(x){
-        ifelse (x > -1 & x < 1,NA, odds.us2prob(odds.indo2us(x)))
+odds.indo2prob <- function(x) {
+  prob <- x
+  prob[] <- NA_real_
+  prob[which(x <= -1)] <- 1 + 1 / (x[which(x <= -1)] - 1)
+  prob[which(x >= 1)] <- 1 / (1 + x[which(x >= 1)])
+  prob
 }
