@@ -9,5 +9,8 @@
 #' @examples
 #' odds.malay2indo(c(1.93,2.05))
 odds.malay2indo <- function (x) {
-        ifelse (x < -1 | x > 1,NA,odds.us2indo(odds.malay2us(x)))
-}
\ No newline at end of file
+  indo <- x
+  indo[] <- NA_real_
+  indo[which(x >= -1 & x != 0 & x <= 1)] <- -1 / x[which(x >= -1 & x != 0 & x <= 1)]
+  indo
+}
