@@ -9,5 +9,9 @@
 #' @examples
 #' odds.malay2prob(c(1.93,2.05))
 odds.malay2prob <- function (x) {
-        ifelse(x < -1 | x > 1,NA,odds.us2prob(odds.malay2us(x)))
-}
\ No newline at end of file
+  prob <- x
+  prob[] <- NA_real_
+  prob[which(x > 0 & x <= 1)] <- 1 / (1 + x[which(x > 0 & x <= 1)])
+  prob[which(x >= -1 & x < 0)] <- 1 / (1 - 1 / x[which(x >= -1 & x < 0)])
+  prob
+}
