@@ -9,6 +9,8 @@
 #' @examples
 #' odds.prob2dec(c(0.5,0.6))
 odds.prob2dec <- function (x) {
-        ifelse (x <= 0 | x >= 1,NA,1/x)
+  dec <- x
+  dec[] <- NA_real_
+  dec[which(x > 0 & x < 1)] <- 1 / x[which(x > 0 & x < 1)]
+  dec
 }
-                
\ No newline at end of file
