@@ -8,6 +8,9 @@
 #'
 #' @examples
 #' odds.prob2hk(c(0.5,0.6))
-odds.prob2hk <- function (x){
-        ifelse (x <= 0 | x >= 1,NA,(1/x)-1)
-}
\ No newline at end of file
+odds.prob2hk <- function (x) {
+  hk <- x
+  hk[] <- NA_real_
+  hk[which(x > 0 & x < 1)] <- 1 / x[which(x > 0 & x < 1)] - 1
+  hk
+}
