@@ -9,5 +9,9 @@
 #' @examples
 #' odds.prob2us(c(0.5,0.6))
 odds.prob2us <- function (x) {
-        ifelse (x <= 0 | x >= 1,NA,ifelse(x <=0.5,100 * (1/x - 1), -100/(1/x - 1)))
-}
\ No newline at end of file
+  us <- x
+  us[] <- NA_real_
+  us[which(x > 0 & x < 1)] <- 100 * (1 / x[which(x > 0 & x < 1)] - 1)
+  us[which(x > 0.5 & x < 1)] <- 100 / (1 - 1 / x[which(x > 0.5 & x < 1)])
+  us
+}
