@@ -9,5 +9,8 @@
 #' @examples
 #' odds.us2indo(c(-200,150))
 odds.us2indo <- function (x) {
-        ifelse(x > -100 & x <100,NA,x/100)   
-}
\ No newline at end of file
+  indo <- x
+  indo[] <- NA_real_
+  indo[which(x <= -100 | x >= 100)] <- x[which(x <= -100 | x >= 100)] / 100
+  indo
+}
